#
# forms.py - Forms used in the application
#
# Copyright 2012, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Tim Flink <tflink@redhat.com>


from flask.ext.wtf import Form
from wtforms import TextField, SelectField, BooleanField, IntegerField
from wtforms import TextAreaField, PasswordField, ValidationError
from wtforms.validators import Required, Optional, Email


def one_proposal(form, field):
    if not (form.freeze_exception.data or form.blocker.data):
        raise ValidationError('You must propose the bug as either a blocker or a freeze exception')


class BugProposeForm(Form):
    bugid = IntegerField(u'Bug ID', [Required()])
    bz_user = TextField(u'Bugzilla Login', [Required(), Email()])
    milestone = SelectField(u'Milestone', [Required()], coerce=int)
    blocker = BooleanField(u'Blocker', [one_proposal])
    freeze_exception = BooleanField(u'Freeze Exception', [one_proposal])
    justification = TextAreaField(u'Justification', [Required()])


class FasBugzillaForm(Form):
    bz_user = TextField(u'Login', [Required(), Email()])
    bz_pass = PasswordField(u'Password', [Required()])
