#
# userinfo.py - ORM class for various user related information
#
# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Martin Krizek <mkrizek@redhat.com>
import string
import random
import crypt

from blockerbugs import db


class UserInfo(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    fas_login = db.Column(db.String(255), unique=True)
    bz_user = db.Column(db.String(255), unique=True)
    api_key_hash = db.Column(db.String(255), unique=True)


    def __init__(self, fas_login=None, bz_user=None):
        self.fas_login = fas_login
        self.bz_user = bz_user

    def generate_api_key(self):
        def _random_string(length=16, chars=string.ascii_letters):
            return ''.join(random.choice(chars) for _ in range(length))

        salt = '$6$%s$' % _random_string()  #SHA-512, man crypt 3
        password = _random_string().encode('utf-8')
        self.api_key_hash = crypt.crypt(password, salt)
        return password

    def check_api_key(self, key):
        if not self.api_key_hash:
            return False
        if self.api_key_hash == crypt.crypt(key, self.api_key_hash):
            return True
        return False


    def __repr__(self):
        return '<userinfo %d: %s>' % (self.fas_login, self.bz_user)
