#
# login.py - a login wrapper
#
# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Martin Krizek <mkrizek@redhat.com>

import bunch
from flask import g, request, redirect


class FakeFas(object):
    fake_user_groups = ['qa-admin']
    fake_user = bunch.Bunch(username='developer',
                            groups=fake_user_groups)

    def __init__(self, app):
        app.before_request(self._set_fas_user)
        self.logged_in = False

    def _set_fas_user(self):
        if self.logged_in:
            g.fas_user = self.fake_user
        else:
            g.fas_user = None

    def _return(self, *args, **kwargs):
        return_url = kwargs.get('return_url')
        if return_url is None:
            if 'next' in request.args.values():
                return_url = request.args.values['next']
            else:
                return_url = request.url
        return redirect(return_url)

    def login(self, *args, **kwargs):
        self.logged_in = True
        return self._return(*args, **kwargs)

    def logout(self, *args, **kwargs):
        self.logged_in = False
        return self._return(*args, **kwargs)
